FlattenToTuple

Struct FlattenToTuple 

pub struct FlattenToTuple<'sval, S> { /* private fields */ }
A stream that flattens the fields of a value onto a tuple.

Implementations

Source

impl<'sval, S: Stream<'sval>> FlattenToTuple<'sval, S>

pub fn new(stream: S, offset: isize) -> Self

Wrap the given stream.

The offset is the current length of the tuple being flattened onto. Call FlattenToTuple::end after streaming a value to get the new length of the tuple.

pub fn end(self) -> (isize, S)

Finish flattening a value.

This method returns the length of the map after flattening that can be used to reconstruct a FlattenToTuple for a future value.