pub struct FlattenToTuple<'sval, S> { /* private fields */ }Expand description
A stream that flattens the fields of a value onto a tuple.
Implementations
Sourceimpl<'sval, S: Stream<'sval>> FlattenToTuple<'sval, S>
impl<'sval, S: Stream<'sval>> FlattenToTuple<'sval, S>
Sourcepub fn new(stream: S, offset: isize) -> Self
pub fn new(stream: S, offset: isize) -> Self
Wrap the given stream.
The offset is the current length of the tuple being flattened onto.
Call FlattenToTuple::end after streaming a value to get the new length of the tuple.